import React from 'react';
import {render, cleanup, waitForElement} from '@testing-library/react';
import ClientConfigContext from '../../ClientConfigContext';
import DashboardPage from './DashboardPage';
import {withContext} from "../../testUtil";

describe('<DashboardPage />', () => {

    afterEach(cleanup);

    it('should fetch ping message', async () => {
        jest.spyOn(window, 'fetch').mockImplementationOnce(() => Promise.resolve({
            text: () => Promise.resolve('test pong'),
        }));
        const {getByText} = render(withContext(<DashboardPage />, ClientConfigContext, {UIBaseRoute: '/ui'}));
        await waitForElement(() => getByText(/Dashboard Page Got ping message from server: test pong/i));
    });


    it('should show error while fetch ping message is failed', async () => {
        jest.spyOn(window, 'fetch').mockImplementationOnce(() => Promise.resolve({
            text: () => Promise.reject(new Error('test error')),
        }));
        const {getByText} = render(withContext(<DashboardPage />, ClientConfigContext, {UIBaseRoute: '/ui'}));
        await waitForElement(() => getByText(/Dashboard Page Got ping message from server: Got Error test error/i));
    });

});
